const std = @import("std");

pub fn build(b: *std.Build) void {
    const target = b.standardTargetOptions(.{});
    const optimize = b.standardOptimizeOption(.{});

    const ssh_path = b.option(
        []const u8,
        "ssh",
        "path to ssh binary",
    ) orelse "ssh";

    const telnet_path = b.option(
        []const u8,
        "telnet",
        "path to telnet binary",
    ) orelse "telnet";

    const exe = b.addExecutable(.{
        .name = "hostapps",
        .root_source_file = .{ .path = "src/main.zig" },
        .target = target,
        .optimize = optimize,
    });

    const build_options = b.addOptions();
    build_options.addOption([]const u8, "ssh_path", ssh_path);
    build_options.addOption([]const u8, "telnet_path", telnet_path);

    exe.root_module.addOptions("build_options", build_options);

    const anzi = b.dependency(
        "anzi",
        .{
            .target = target,
            .optimize = optimize,
        },
    );

    exe.root_module.addImport("anzi", anzi.module("anzi"));

    const logz = b.dependency(
        "logz",
        .{
            .target = target,
            .optimize = optimize,
        },
    );

    exe.root_module.addImport("logz", logz.module("logz"));

    const yazap = b.dependency(
        "yazap",
        .{
            .target = target,
            .optimize = optimize,
        },
    );

    exe.root_module.addImport("yazap", yazap.module("yazap"));

    b.installArtifact(exe);

    const run_cmd = b.addRunArtifact(exe);

    run_cmd.step.dependOn(b.getInstallStep());

    if (b.args) |args| {
        run_cmd.addArgs(args);
    }

    const run_step = b.step("run", "Run the app");
    run_step.dependOn(&run_cmd.step);

    const exe_unit_tests = b.addTest(.{
        .root_source_file = .{ .path = "src/main.zig" },
        .target = target,
        .optimize = optimize,
    });

    const run_exe_unit_tests = b.addRunArtifact(exe_unit_tests);

    const test_step = b.step("test", "Run unit tests");
    test_step.dependOn(&run_exe_unit_tests.step);
}
